==> qore-0.9.2.tar.bz2: qore-0.9.2/docs/lang/html/search/variables_13.js <==
var searchData=
[
  ['varchar',['VARCHAR',['../group__sql__constants.html#ga90979385c781ed49b4f726f32a48a9b5',1,'Qore::SQL']]],
  ['vdiscard',['VDISCARD',['../group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'Qore']]],
  ['vdsusp',['VDSUSP',['../group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'Qore']]],
  ['veof',['VEOF',['../group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'Qore']]],
  ['veol',['VEOL',['../group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'Qore']]],
  ['veol2',['VEOL2',['../group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'Qore']]],
  ['verase',['VERASE',['../group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'Qore']]],
  ['versionmajor',['VersionMajor',['../group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'Qore']]],
  ['versionminor',['VersionMinor',['../group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'Qore']]],
  ['versionstring',['VersionString',['../group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'Qore']]],
  ['versionsub',['VersionSub',['../group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'Qore']]],
  ['vintr',['VINTR',['../group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'Qore']]],
  ['vkill',['VKILL',['../group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'Qore']]],
  ['vlnext',['VLNEXT',['../group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'Qore']]],
  ['vmin',['VMIN',['../group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'Qore']]],
  ['vquit',['VQUIT',['../group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'Qore']]],
  ['vreprint',['VREPRINT',['../group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'Qore']]],
  ['vstart',['VSTART',['../group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'Qore']]],
  ['vstatus',['VSTATUS',['../group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'Qore']]],
  ['vstop',['VSTOP',['../group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'Qore']]],
  ['vsusp',['VSUSP',['../group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'Qore']]],
  ['vtime',['VTIME',['../group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'Qore']]],
  ['vwerase',['VWERASE',['../group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'Qore']]]
];

==> qore-0.9.3.tar.bz2: qore-0.9.3/docs/lang/html/search/variables_13.js <==
var searchData=
[
  ['varchar',['VARCHAR',['../group__sql__constants.html#ga245358d11b9f00fb824fd0281f78728a',1,'Qore::Qore::Qore::SQL']]],
  ['vdiscard',['VDISCARD',['../group__tattr__control__character__constants.html#gab6f8f9e09ba859fab513af01c6077242',1,'Qore']]],
  ['vdsusp',['VDSUSP',['../group__tattr__control__character__constants.html#gaf23acc31adc6c5ed8d92fca4fe3f9ebb',1,'Qore']]],
  ['veof',['VEOF',['../group__tattr__control__character__constants.html#gaeb2dd99e6d8bae0da14955d2b2b4ab83',1,'Qore']]],
  ['veol',['VEOL',['../group__tattr__control__character__constants.html#gaaed108b862512be1d44add99b3ae19f4',1,'Qore']]],
  ['veol2',['VEOL2',['../group__tattr__control__character__constants.html#ga36824df04eb03f180576584315d1438f',1,'Qore']]],
  ['verase',['VERASE',['../group__tattr__control__character__constants.html#ga32e03f1d721f1d42a4844600118c3ba7',1,'Qore']]],
  ['versionmajor',['VersionMajor',['../group__system__and__build__constants.html#ga981ec5d46693e04ec68a953c96950b97',1,'Qore']]],
  ['versionminor',['VersionMinor',['../group__system__and__build__constants.html#ga2951ba69a965973d76898d671270fd9e',1,'Qore']]],
  ['versionstring',['VersionString',['../group__system__and__build__constants.html#gadc4aece84a7f703cb7f2da77f18980b8',1,'Qore']]],
  ['versionsub',['VersionSub',['../group__system__and__build__constants.html#ga92cc5129c80534fbc9c887321a582264',1,'Qore']]],
  ['vintr',['VINTR',['../group__tattr__control__character__constants.html#gaf2a5a8591c92d2763e19ea5878d60da0',1,'Qore']]],
  ['vkill',['VKILL',['../group__tattr__control__character__constants.html#gaceffb080408e13e1d1e5ba06fa38b955',1,'Qore']]],
  ['vlnext',['VLNEXT',['../group__tattr__control__character__constants.html#ga43c58434668c6190c7a3fa2c93a1069a',1,'Qore']]],
  ['vmin',['VMIN',['../group__tattr__control__character__constants.html#gafeff0497d2f931b98867a14110118092',1,'Qore']]],
  ['vquit',['VQUIT',['../group__tattr__control__character__constants.html#gad57b68bc7741d323990953974d9d3e43',1,'Qore']]],
  ['vreprint',['VREPRINT',['../group__tattr__control__character__constants.html#ga459d4e28cf1d41957293edbf1bdeb49f',1,'Qore']]],
  ['vstart',['VSTART',['../group__tattr__control__character__constants.html#ga99de89c1439de57a85c1dac65cccb16f',1,'Qore']]],
  ['vstatus',['VSTATUS',['../group__tattr__control__character__constants.html#ga47fdcbe36715d78988d7aa7451495520',1,'Qore']]],
  ['vstop',['VSTOP',['../group__tattr__control__character__constants.html#gadade029ba0b6e2127b9d89c226b4b4c4',1,'Qore']]],
  ['vsusp',['VSUSP',['../group__tattr__control__character__constants.html#ga74344c52f51ef60c658791c9a0c62abc',1,'Qore']]],
  ['vtime',['VTIME',['../group__tattr__control__character__constants.html#gab502b713036bffa3836f933197f824bf',1,'Qore']]],
  ['vwerase',['VWERASE',['../group__tattr__control__character__constants.html#ga0cd6d66463f03290809a41c6209bd96b',1,'Qore']]]
];
